@@ -931,28 +931,6 @@ void cidr::set(const char *cp)
     }
 }
 
-Socket::inet::inet(int fam)
-{
-	const sockaddr_storage sa = Socket::address::loopback(fam);
-	store((struct sockaddr *)&sa);
-}
-
-void Socket::inet::store(struct sockaddr *addr)
-{
-	memset(&storage, 0, sizeof(storage));
-	switch(addr->sa_family) {
-	case AF_INET:
-		memcpy(&storage.ipv4, (struct sockaddr_in*)(addr), sizeof(struct sockaddr_in));
-		break;
-#ifdef	AF_INET6
-	case AF_INET6:
-		memcpy(&storage.ipv6, (struct sockaddr_in6*)(addr), sizeof(struct sockaddr_in6));
-		break;
-
-#endif
-	}
-}
-
 Socket::address::address(int family, const char *a, int type, int protocol)
 {
     assert(a != NULL && *a != 0);
@@ -3580,12 +3558,14 @@ bool Socket::is_numeric(const char *str)
 int Socket::local(socket_t sock, struct sockaddr_storage *addr)
 {
     socklen_t slen = sizeof(sockaddr_storage);
+	memset(addr, 0, slen);
     return _getsockname_(sock, (struct sockaddr *)addr, &slen);
 }
 
 int Socket::remote(socket_t sock, struct sockaddr_storage *addr)
 {
     socklen_t slen = sizeof(sockaddr_storage);
+	memset(addr, 0, slen);
     return _getpeername_(sock, (struct sockaddr *)addr, &slen);
 }
 
