@@ -100,7 +100,6 @@ class __EXPORT SharedAccess : protected UnlockAccess
 protected:
     virtual ~SharedAccess();
 
-protected:
     /**
      * Access interface to share lock the object.
      */
@@ -145,6 +144,8 @@ class __EXPORT exclusive_access
 private:
     ExclusiveAccess *lock;
 
+    __DELETE_COPY(exclusive_access);
+
 public:
     /**
      * Create an instance of an exclusive object reference.
@@ -202,6 +203,10 @@ public:
      */
     shared_access(SharedAccess *object);
 
+    shared_access(const shared_access& copy);
+
+    shared_access& operator=(const shared_access& copy);
+
     /**
      * Destroy reference to shared locked object, release lock.
      */
