@@ -348,88 +348,6 @@ public:
      */
     static void release(struct addrinfo *list);
 
-    class __EXPORT inet
-    {
-    private:
-        union {
-    #ifdef  AF_INET6
-            struct sockaddr_in6 ipv6;
-    #endif
-            struct sockaddr_in ipv4;
-        } storage;
-
-        void store(struct sockaddr *addr);
-
-    public:
-        inet(int famly = AF_INET);
-
-        inline inet(struct sockaddr *addr) {
-            store(addr);
-        }
-
-        inline inet(const inet& copy) {
-            memcpy(&storage, &copy.storage, sizeof(storage));
-        }
-
-        inline int family() {
-            return storage.ipv4.sin_family;
-        }
-
-        inline const struct sockaddr_in *in4() const {
-            if(storage.ipv4.sin_family == AF_INET)
-                return &storage.ipv4;
-            return NULL;
-        }
-
-        inline const struct sockaddr *in() const {
-            return (struct sockaddr *)&storage;
-        }
-
-    #ifdef  AF_INET6
-        inline const struct sockaddr_in6 *in6() const {
-            if(storage.ipv6.sin6_family == AF_INET6)
-                return &storage.ipv6;
-            return NULL;
-        }
-    #else
-        inline const struct sockaddr_in6 *in6() const {
-            return NULL;
-        }
-    #endif
-
-        inline operator const struct sockaddr *() const {
-            return (struct sockaddr *)&storage;
-        }
-
-        inline struct sockaddr *operator*() {
-            return (struct sockaddr *)&storage;
-        }
-
-        inline inet& operator=(struct sockaddr *addr) {
-            store(addr);
-            return *this;
-        }
-
-        inline bool operator==(struct sockaddr *addr) const {
-            return Socket::equal((const struct sockaddr *)&storage, addr);
-        }     
-
-        inline bool operator==(const inet& addr) const {
-            return Socket::equal((const struct sockaddr *)&storage, (const struct sockaddr *)(&addr.storage));
-        }     
-
-        inline bool operator!=(const struct sockaddr *addr) const {
-            return !Socket::equal((const struct sockaddr *)&storage, addr);
-        }     
-
-        inline bool operator!=(const inet& addr) const {
-            return !Socket::equal((const struct sockaddr *)&storage, (const struct sockaddr *)(&addr.storage));
-        }     
-
-    };
-
-    typedef class inet inet_t;
-
     /**
      * A generic socket address class.  This class uses the addrinfo list
      * to store socket multiple addresses in a protocol and family
@@ -1752,13 +1670,22 @@ public:
      */
     static short service(const struct sockaddr *address);
 
+    inline static in_port_t port(const struct sockaddr *address) {
+        return service(address);
+    }
+
     /**
      * Get the service port of an inet socket.
      * @param address of internet socket to examine.
      * @return service port number.
      */
-    inline static short service(const struct sockaddr_internet *address)
-        {return service((const struct sockaddr *)address);}
+    inline static short service(const struct sockaddr_internet *address) {
+        return service((const struct sockaddr *)address);
+    }
+
+    inline static in_port_t port(const struct sockaddr_internet *address) {
+        return service((const struct sockaddr *)address);
+    }
 
     /**
      * Convert a socket address and service into a hash map index.
@@ -2121,7 +2048,128 @@ inline bool eq_subnet(const struct sockaddr *s1, const struct sockaddr *s2)
 String str(Socket& so, strsize_t size);
 
 namespace Type {
-    typedef Socket::inet InetAddress;
+
+    class SockAddress
+    {
+    private:
+        struct sockaddr_storage storage;
+
+    public:
+        inline SockAddress() {
+            memset(&storage, 0, sizeof(storage));
+        }
+
+        inline SockAddress(const SockAddress& copy) {
+            memcpy(&storage, &copy.storage, sizeof(storage));
+        }
+
+        inline SockAddress(const struct sockaddr *addr) {
+            Socket::store(&storage, addr);
+        }
+
+        inline SockAddress& operator=(const SockAddress& copy) {
+            memcpy(&storage, &copy.storage, sizeof(storage));
+            return *this;
+        }
+
+        inline SockAddress& operator=(const struct sockaddr *addr) {
+            Socket::store(&storage, addr);
+            return *this;
+        }
+
+        inline operator const struct sockaddr *() const {
+            return (const struct sockaddr*)&storage;
+        }
+
+        inline struct sockaddr *operator*() {
+            return (struct sockaddr *)&storage;
+        }
+
+        inline const struct sockaddr *get() const {
+            return (const struct sockaddr *)&storage;
+        }
+
+        inline socklen_t size() {
+            return sizeof(storage);
+        }
+
+        inline bool operator==(const SockAddress& check) const {
+            return Socket::equal(get(), check.get());
+        }
+
+        inline bool operator!=(const SockAddress& check) const {
+            return !Socket::equal(get(), check.get());
+        }
+
+        inline bool operator==(const struct sockaddr *check) const {
+            return Socket::equal(get(), check);
+        }
+
+        inline bool operator!=(const struct sockaddr *check) const {
+            return !Socket::equal(get(), check);
+        }
+    };
+
+    class InetAddress
+    {
+    private:
+        struct sockaddr_internet storage;
+
+    public:
+        inline InetAddress() {
+            memset(&storage, 0, sizeof(storage));
+        }
+
+        inline InetAddress(const InetAddress& copy) {
+            memcpy(&storage, &copy.storage, sizeof(storage));
+        }
+
+        inline InetAddress(const struct sockaddr *addr) {
+            Socket::store(&storage, addr);
+        }
+
+        inline InetAddress& operator=(const InetAddress& copy) {
+            memcpy(&storage, &copy.storage, sizeof(storage));
+            return *this;
+        }
+
+        inline InetAddress& operator=(const struct sockaddr *addr) {
+            Socket::store(&storage, addr);
+            return *this;
+        }
+
+        inline operator const struct sockaddr *() const {
+            return (const struct sockaddr*)&storage;
+        }
+
+        inline struct sockaddr *operator*() {
+            return (struct sockaddr *)&storage;
+        }
+
+        inline const struct sockaddr *get() const {
+            return (const struct sockaddr *)&storage;
+        }
+
+        inline socklen_t size() {
+            return sizeof(storage);
+        }
+
+        inline bool operator==(const SockAddress& check) const {
+            return Socket::equal(get(), check.get());
+        }
+
+        inline bool operator!=(const SockAddress& check) const {
+            return !Socket::equal(get(), check.get());
+        }
+
+        inline bool operator==(const struct sockaddr *check) const {
+            return Socket::equal(get(), check);
+        }
+
+        inline bool operator!=(const struct sockaddr *check) const {
+            return !Socket::equal(get(), check);
+        }
+    };
 }
 
 typedef TCPServer   tcpserv_t;
