@@ -84,36 +84,112 @@ secure::string Digest::uuid(const char *name, const unsigned char *ns)
     return secure::string(buf);
 }
 
+secure::keybytes Digest::md5(const uint8_t *mem, size_t size)
+{
+    if(!mem || !size || !has("md5"))
+        return secure::keybytes();
+
+    digest_t digest("md5");
+    digest.put(mem, size);
+    mem = digest.get();
+    return secure::keybytes(mem, digest.size() * 8, secure::KEY_DIGEST);
+}
+
+secure::keybytes Digest::sha1(const uint8_t *mem, size_t size)
+{
+    if(!mem || !size || !has("sha1"))
+        return secure::keybytes();
+
+    digest_t digest("sha1");
+    digest.put(mem, size);
+    mem = digest.get();
+    return secure::keybytes(mem, digest.size() * 8, secure::KEY_DIGEST);
+}
+
+secure::keybytes Digest::sha256(const uint8_t *mem, size_t size)
+{
+    if(!has("sha256") || !mem || !size)
+        return secure::keybytes();
+
+    digest_t digest("sha256");
+    digest.put(mem, size);
+    mem = digest.get();
+    return secure::keybytes(mem, digest.size() * 8, secure::KEY_DIGEST);
+}
+
+secure::keybytes Digest::sha384(const uint8_t *mem, size_t size)
+{
+    if(!mem || !has("sha384") || !size)
+        return secure::keybytes();
+
+    digest_t digest("sha384");
+    digest.put(mem, size);
+    mem = digest.get();
+    return secure::keybytes(mem, digest.size() * 8, secure::KEY_DIGEST);
+}
+
 secure::string Digest::md5(const char *text)
 {
-    if(!has("md5"))
+    if(!text || !has("md5"))
         return secure::string();
 
-    digest_t digest = "md5";
+    digest_t digest("md5");
     digest.puts(text);
     return secure::string(*digest, secure::MD5_DIGEST);
 }
 
 secure::string Digest::sha1(const char *text)
 {
-    if(!has("sha1"))
+    if(!text || !has("sha1"))
         return secure::string();
 
-    digest_t digest = "sha1";
+    digest_t digest("sha1");
     digest.puts(text);
     return secure::string(*digest, secure::SHA_DIGEST);
 }
 
 secure::string Digest::sha256(const char *text)
 {
-    if(!has("sha256"))
+    if(!text || !has("sha256"))
         return secure::string();
 
-    digest_t digest = "sha256";
+    digest_t digest("sha256");
     digest.puts(text);
     return secure::string(*digest, secure::SHA_DIGEST);
 }
 
+secure::string Digest::sha384(const char *text)
+{
+    if(!text || !has("sha384"))
+        return secure::string();
+
+    digest_t digest("sha384");
+    digest.puts(text);
+    return secure::string(*digest, secure::SHA_DIGEST);
+}
+
+secure::keybytes HMAC::sha256(secure::keybytes key, const uint8_t *mem, size_t size)
+{
+    if(!mem || !has("sha256"))
+        return secure::keybytes();
+
+	hmac_t hmac("sha256", key);
+    hmac.put(mem, size);
+    mem = hmac.get();
+    return secure::keybytes(mem, hmac.size() * 8, secure::KEY_DIGEST);
+}
+
+secure::keybytes HMAC::sha384(secure::keybytes key, const uint8_t *mem, size_t size)
+{
+    if(!mem || !has("sha384"))
+        return secure::keybytes();
+
+	hmac_t hmac("sha384", key);
+    hmac.put(mem, size);
+    mem = hmac.get();
+    return secure::keybytes(mem, hmac.size() * 8, secure::KEY_DIGEST);
+}
+
 #if defined(_MSWINDOWS_)
 
 static void cexport(HCERTSTORE ca, FILE *fp)
@@ -281,6 +357,17 @@ HMAC::HMAC(const char *digest, const char *key, size_t len)
     set(digest, key, len);
 }
 
+HMAC::HMAC(const char *digest, const secure::keybytes& key)
+{
+    context = NULL;
+    bufsize = 0;
+    hmactype = NULL;
+    hmacid = 0;
+    textbuf[0] = 0;
+
+    set(digest, (const char *)*key, key.size() / 8);
+}
+
 HMAC::~HMAC()
 {
     release();
@@ -400,7 +487,7 @@ size_t Cipher::Key::get(uint8_t *keyout, uint8_t *ivout)
     return size;
 }
 
-bool Cipher::Key::set(const char *cipher, secure::keybytes& iv)
+bool Cipher::Key::set(const char *cipher, const secure::keybytes& iv)
 {
     const uint8_t *ivp = *iv;
     size_t size = iv.size() / 8;
@@ -418,7 +505,7 @@ bool Cipher::Key::set(const char *cipher, secure::keybytes& iv)
     return true;
 }
 
-bool Cipher::Key::set(secure::keybytes& key) 
+bool Cipher::Key::set(const secure::keybytes& key) 
 {
     const uint8_t *kvp = *key;
     size_t size = key.size() / 8;
